summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorThomas Zander <t.zander@nokia.com>2010-08-11 11:46:38 (GMT)
committerThomas Zander <t.zander@nokia.com>2010-08-11 12:08:10 (GMT)
commit0cafff970c52f982d5acec368b5b5fdab319688d (patch)
tree19e0d7d361166ca6cc48963b0a24877c8159a55b /src
parent530db672296a3234803142ff6b7e3b25c5e9abec (diff)
downloadQt-0cafff970c52f982d5acec368b5b5fdab319688d.zip
Qt-0cafff970c52f982d5acec368b5b5fdab319688d.tar.gz
Qt-0cafff970c52f982d5acec368b5b5fdab319688d.tar.bz2
Fix typos in docs
Reviewed-by: David Boddie
Diffstat (limited to 'src')
-rw-r--r--src/declarative/graphicsitems/qdeclarativerepeater.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/declarative/graphicsitems/qdeclarativerepeater.cpp b/src/declarative/graphicsitems/qdeclarativerepeater.cpp
index 2b268fb..68e7e9a 100644
--- a/src/declarative/graphicsitems/qdeclarativerepeater.cpp
+++ b/src/declarative/graphicsitems/qdeclarativerepeater.cpp
@@ -133,13 +133,13 @@ QDeclarativeRepeaterPrivate::~QDeclarativeRepeaterPrivate()
create items as they are required.
Also, note that Repeater is \l {Item}-based, and can only repeat \l {Item}-derived objects.
- For example, it cannot be used to repeat QtObjects:
+ For example, it cannot be used to repeat QObjects:
\badcode
Item {
//XXX does not work! Can't repeat QtObject as it doesn't derive from Item.
Repeater {
model: 10
- QtObject {}
+ QObject {}
}
}
\endcode
@@ -133,13 +133,13 @@ QDeclarativeRepeaterPrivate::~QDeclarativeRepeaterPrivate()
\badcode
Item {
- //XXX does not work! Can't repeat QtObject as it doesn't derive from Item.
+ //XXX does not work! Can't repeat QObject as it doesn't derive from Item.
Repeater {
model: 10